Description Usage Arguments Value See Also
View source: R/ArchitectureModel.R
A convenience function to calculate summary statistics and evaluate their loss. Not recommended for regular use, for which direct inference via lossfunctionss and lossfunction is recommended.
1 | lossfunctionp(s, ref)
|
s |
Genomic Architecture parameter for estimation |
ref |
A list containing: ref$dat: A data frame of (f,beta) pairs; ref$bins: the histogram bins to use; and ref$thresholds: the tail areas to compare (in s.d units). |
The loss as returned by lossfunction, run of the summary statistics returned by lossfunctionss.
fullsearch for inference.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.