Description Usage Arguments Value
View source: R/ArchitectureSimulate.R
Keep at most k random SNPs from a dataframe.
1 | random_data(testdata, k = 100)
|
testdata |
The data frame containing frequency in the first column. |
k |
The number of SNPs to retain |
A dataframe the same shape as provided with only min(k,dim(testdata)[1]) SNPs.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.