Description Format See Also Examples
Simulated data using s=-0.5 and only the top 10% (10k) SNPs
retained by variance explained. This masking leads to a complex
inference problem typical of real data, but is not a problem for
the link{genomicarchitecture} approach.
An data frame containing 4 columns, "f","beta","varexplained","propexplained". Only the first two are required for inference.
make_test_data to generate your own simulated data, and top_data to threshold it. fullsearch to perform inference and architectureplot to plot the results.
1 2 3 4 5 6 | ## Not run:
data(topdata)
topres=fullsearch(dat=topdata)
architectureplot(topdata,topres)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.