Description Usage Arguments Value See Also
View source: R/ArchitectureSimulate.R
Filter data to keep only the top k by proportion of variance explained, which must be provided in a column called 'propexplained'.
1 | top_data(testdata, k = 100)
|
testdata |
The data frame containing frequency in the first column. |
k |
The number of SNPs to retain |
A dataframe the same shape as provided with only the top k SNPs.
make_test_data which simulates the data and gives a complete example.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.